function chlorine2(noiseThreshold, parentThreshold){
	
	noiseThreshold = parseFloat(noiseThreshold);
	parentThreshold = parseFloat(parentThreshold);
	
	
	var massSpec = _default.getMSSpectrum();
	
	var chlorine2 = false;
	var em = massSpec.getMaxMZ();
	var mass = em - 4;
	var finish = massSpec.getMinMZ();
	var trapMass = 0;
	
	do{
		
		// get the intensity at the current location
		var am = massSpec.getIntensity(mass);
		
		// if the intensity is above the noise
		if(am > noiseThreshold){
			
			// set the trap mass if the intensity is high enough.
			// this will cause the loop to end soon after finding it
			if(trapMass == 0 && am > parentThreshold){
				trapMass = mass;
				if(finish < (mass - 8)){
					finish = mass - 8;
				}
			}
			
			// get intensity ratios
			var ratio1 = ratio(massSpec.getIntensity(mass + 2), am);
			var ratio2 = ratio(massSpec.getIntensity(mass + 4), am);
			var ratio3 = ratio(massSpec.getIntensity(mass + 1), am);
			
			// if the peaks match the ratios
			if(ratio1 > 0.55 && ratio1 < 0.72 &&
			   ratio2 > 0.07 && ratio2 < 0.15 &&
			   ratio3 < 0.3) {
				
				var threshold = 0;
				
				// if there are values above the ion cluster
				// use them to calculate the threshold
				if(em > (mass + 4)){
					
					// for every value above the ion cluster get the intensity
					// and compare it the the current threshold
					for( var i = em ; i > (mass + 4) ; i--){
						var am2 = massSpec.getIntensity(i);
						if(am2 > threshold){
							threshold = am2;
						}
					}
					
				// otherwise, assume noise to be about 10% of the intensity
				}else{
					threshold = am * 0.1;
				}
				
				if( noIrrationalFragments(massSpec, mass, threshold) ){
					chlorine2 = true;
					break;
				}
				
			}
			
		}
		
		mass = mass - 1;
		
	}while(mass > finish)
	
	return chlorine2;
	
}

function ratio(inten1, inten2){
	
	if(inten2 == 0){
		return 0;
	}
	
	return inten1/inten2;
	
}

function noIrrationalFragments(massSpec, mass, threshold){
	
	var noIrrFrag = true;
	var am = massSpec.getIntensity(mass);
	var testMass = mass - 3;
	var lowMass = mass - 10;
	
	if(threshold < am * 0.1){
		threshold = am * 0.1;
	}
	
	do{
		
		if(massSpec.getIntensity(testMass) > threshold){
			noIrrFrag = false;
			break;
		}
		testMass = testMass - 1;
		
	}while(testMass > lowMass)
	
	return noIrrFrag;
	
}